describe('Visit Home Prauge Website', () => {
  it('Successfully loads home page', () => {
    // Ignore uncaught exceptions
    cy.on('uncaught:exception', (err, runnable) => {
      // return false to prevent the error from failing this test
      if (err.message.includes('gtag is not defined')) {
        return false;
      }
    });

    cy.visit('http://homeprague/');
    cy.get('[href="about.php"]').click();
    cy.get('#name').type("Vasily");
    cy.get('#surname').type("Gusev");
    cy.get('#email').type("gusevvas@mail.com");
    cy.get('#phone').type("+420666666666");
    cy.get('#message').type("Dobrý den, \nzaujala mi Vaše nabídka bytu na Václavském náměstí"+
    "\nA proto bych chtěl se domluvit o prohlídce"+
    "\nProsím o zavolání nebo nepsání emailu.\nDěkuji.\nVasily Gusev.");
    cy.get('#submitButton').click();
    cy.get('.modal-content > p').should('have.text','Děkujeme Vám za odeslání nabídky, brzy Vás budeme kontaktovat.');
    cy.get('.modal-content > button').click();
  });
});

describe('Visit Home Prauge Website - check search', () => {
  it('Successfully loads  home page', () => {
    // Ignore uncaught exceptions
    cy.on('uncaught:exception', (err, runnable) => {
      // return false to prevent the error from failing this test
      if (err.message.includes('gtag is not defined')) {
        return false;
      }
    });

    cy.visit('http://homeprague/');
    cy.get('[href="search.php"]').click();
    cy.get('.dispositions > :nth-child(1) > :nth-child(3) > input').click();
    cy.get('.dispositions > :nth-child(2) > :nth-child(1)').click();
    cy.get('.dispositions > :nth-child(2) > :nth-child(3)').click();
    cy.get('.localities > :nth-child(1) > :nth-child(2)').click();
    cy.get(':nth-child(1) > .property-info > .description').should('have.text','Pronájem bytu 1+kk');
    cy.get(':nth-child(2) > .property-info > .description').should('have.text','Prodej bytu 3+kk');
  });
});

describe('Check the offer on Home Prauge Website', () => {
  it('Successfully loads home page', () => {
    // Ignore uncaught exceptions
    cy.on('uncaught:exception', (err, runnable) => {
      // return false to prevent the error from failing this test
      if (err.message.includes('gtag is not defined')) {
        return false;
      }
    });

    cy.visit('http://homeprague/');
    cy.get('[href="detail.php?property=1"] > .property-item > .property-image > img').click();
    cy.wait(2000);
    cy.get('[src="properties/1/2.png"]').click();
    cy.wait(2000);
    cy.get('[src="properties/1/3.png"]')
    cy.wait(2000);
    cy.get('[src="properties/1/4.png"]');
    cy.wait(2000);
    cy.get('.property-description > :nth-child(2)').should("have.text",'\nTento byt 1+kk na Lázeňské ulici v Praze 1, na Malé Straně, představuje skutečnou oázu klidu a luxusu. Obývací prostor je navržen s otevřeným konceptem, spojujícím spánek, odpočinek a pracovní činnosti v harmonickém celku. Vyznačuje se moderním designem, jemnými tkaninami a teplými neutrálními tóny, které vytvářejí pocit klidu a pohody. Ložnice je vybavena velkou a pohodlnou postelí, ideální pro odpočinek po dlouhém dni. Dominantní okno od podlahy až ke stropu nabízí dechberoucí výhled na noční oblohu a panorama města.');
  });
});

describe('Integration Test: Comment Functionality', () => {
  it('Allows a user to add and view comments on an article', () => {
    const articleId = '123';
    const commentText = 'This is a test comment.';

    // Visits an article with ID 123
    cy.visit(`/articles/${articleId}`);

    // Checks if the page is loadede
    cy.contains('h1', 'Article Title').should('be.visible'); 

    // Add a comment
    cy.get('textarea[name="comment"]').type(commentText);
    cy.get('form').submit();

    // Check if a comment was added
    cy.contains('.comment', commentText).should('be.visible'); // Předpokládáme, že komentáře se zobrazují v elementu s třídou 'comment'

    // Checks if the comment was added
    cy.request(`/api/articles/${articleId}/comments`).then((response) => {
      expect(response.body).to.deep.include({ content: commentText });
    });
  });
});