const { test, expect } = require('@playwright/test');

test.describe('Login API Testing', () => {
  test('POST - Validate login and response structure', async ({ request }) => {
    const response = await request.post('https://dummyjson.com/auth/login', {
      headers: { 'Content-Type': 'application/json' },
      data: {
        username: 'kminchelle',
        password: '0lelplR',
        // expiresInMins: 60, // optional, include if needed
      },
    });

    // Validate the response status code is 200 OK
    expect(response.status()).toBe(200);

    // Parse the response body
    const responseBody = await response.json();

    // Validate that the response has an 'username' property
    expect(responseBody).toHaveProperty('username');

    // Validate that the response has an 'email' property
    expect(responseBody).toHaveProperty('email');

    // Validate that the response has a 'token' property
    expect(responseBody).toHaveProperty('token');
  });
});

test.describe('getProducts', () => {
  test('GET - Validate the response of the API', async ({ request }) => {
    const response = await request.get('https://dummyjson.com/products/1');

    // Validate that the response code should be 200
    expect(response.status()).toBe(200);

    // Parse the response body
    const responseBody = await response.json();

    // Validate that the response has an 'id' property
    expect(responseBody).toHaveProperty('id');

    // Validate that the response has a 'title' property
    expect(responseBody).toHaveProperty('title');

    // Validate that the response has an 'images' property
    expect(responseBody).toHaveProperty('images');
  });
});

test.describe('GET Carts API', () => {
  test('GET - Validate response structure and status code', async ({ request }) => {
    const response = await request.get('https://dummyjson.com/carts');

    // Validate that the response code should be 200
    expect(response.status()).toBe(200);

    // Parse the response body
    const responseBody = await response.json();

    // Validate that the response body has a 'total' property
    expect(responseBody).toHaveProperty('total');

    // Validate that the response body has a 'limit' property
    expect(responseBody).toHaveProperty('limit');
  });
});
