const { test, expect } = require('@playwright/test');

test.describe('Login API Testing', () => {
  test('PUT - Update Ingridient Data validate structure and status code', async ({ request }) => {
    const response = await request.put('http://127.0.0.1:8000/ingredient/update', {
      headers: { 'Content-Type': 'application/json' },
      data: {
        "name": "avocado",
         "id": "fdcf7b9a75b21ff5"
        // expiresInMins: 60, // optional, include if needed
      },
    });

    // Validate the response status code is 200 OK
    expect(response.status()).toBe(200);

    // Parse the response body
    const responseBody = await response.json();

    // Validate that the response has an 'name' property
    expect(responseBody).toHaveProperty('name');

    // Validate that the response has an 'id' property
    expect(responseBody).toHaveProperty('id');

  });
});

test.describe('getRecipe list', () => {
  test('GET - Recipe list validate status code', async ({ request }) => {
    const response = await request.get('http://127.0.0.1:8000/recipe/list');

    // Validate that the response code should be 200
    expect(response.status()).toBe(200);


  });
});

test.describe('POST create recipe API', () => {
  test('POST - Validate response structure and status code', async ({ request }) => {
    const response = await request.post('http://127.0.0.1:8000/recipe/create',
    {
          headers: { 'Content-Type': 'application/json' },
    data: {
      "name": "az",
      "description": "az",
      "categoryIdList": ["f9e264c6149c7e43"],
      "ingredientList": [{"id": "67f6b85d20a965a9", "amount": 1, "unit": "kg"}],
      "imageId": "CreateRecipeMockup.png",
      "method":"Handmade"
   }
      ,}

    );

    // Validate that the response code should be 200
    expect(response.status()).toBe(200);

    // Parse the response body
    const responseBody = await response.json();

    // Validate that the response body has a 'name' property
    expect(responseBody).toHaveProperty('name');

    // Validate that the response body has a 'id' property
    expect(responseBody).toHaveProperty('id');
      
    // Validate that the response body has a 'categoryIdList' property
      expect(responseBody).toHaveProperty('categoryIdList');

          // Validate that the response body has a 'ingredientList' property
    expect(responseBody).toHaveProperty('ingredientList');
      
    // Validate that the response body has a 'imageId' property
      expect(responseBody).toHaveProperty('imageId');
  });
});
