const { test, expect } = require('@playwright/test');

test.describe('Visit PEF CZU Website', () => {
  test('Visit PEF CZU Website and checkparking', async ({ page }) => {
    // Visit the PEF CZU home page
    page.goto('https://www.pef.czu.cz/', {waitUntil: 'networkidle'});

    // Click on the second item in the navigation menu
    await page.waitForSelector('#nav > ul > :nth-child(2) > a', { state: 'visible', timeout: 5000 });
    await page.click('#nav > ul > :nth-child(2) > a');
    // Click on the fifth item under a specific role in the navigation menu
    await page.click('#nav > [role="menubar"] > li.active > ul > :nth-child(5) > a');

    // Click on an element specified by its aria-labelledby attribute
    await page.waitForSelector('[aria-labelledby="widget-3913-item-8485"] > article > .tileInner > .tile__data');
    await page.click('[aria-labelledby="widget-3913-item-8485"] > article > .tileInner > .tile__data');

    // Check if an element with a specific ID has the expected text
    await expect(page.locator('#widget-283-heading')).toHaveText('Parkování v areálu ČZU');
  },{ timeout: 60000 });
});

test.describe('Buy CZU Book', () => {
  test('Buy CZU Book Eshop CZU', async ({ page }) => {
    // Visit the website
     page.goto('https://eshop.czu.cz/');

    // Click on the first product image
    await page.click('.codeblock > .category-products > .products-grid > .first > .product-image > img');
    
    // Click on the add to cart button
    await page.click('.add-to-cart > .button > :nth-child(1) > span');
    
    // Check for success message
    await expect(page.locator('.success-msg > ul > li > span')).toHaveText('Teorie účetnictví - příklady, 362 was added to your shopping cart.');
    
    // Navigate to the cart
    await page.click('.top-link-cart');
    
    // Proceed to checkout
    await page.click('.totals > .checkout-types > li > .button > :nth-child(1) > span');
    
    // Click to choose guest/register checkout
    await page.click('.col-1 > .form-list > :nth-child(1) > label');
    await page.click('#onepage-guest-register-button > :nth-child(1) > span');
    
    // Fill in billing information
    await page.fill('#billing\\:firstname', "Testovácí");
    await page.fill('#billing\\:lastname', "Uživatel");
    await page.fill('#billing\\:email', "someone@example.com");
    await page.fill('#billing\\:street1', "Nějaká adresa 1");
    await page.fill('#billing\\:city', "Praha");
    await page.fill('#billing\\:postcode', "12000");
    await page.fill('#billing\\:telephone', "666666666");
    
    // Proceed to the next step
    await page.click('#billing-buttons-container > .button > :nth-child(1) > span');
    
    // Choose shipping method
    await page.click('#s_method_flatrate_flatrate');
    await page.click('#shipping-method-buttons-container > .button > :nth-child(1) > span');
    
    // Finalize the payment method selection
    await page.click('#payment-buttons-container > .button > :nth-child(1) > span');
    
    // Wait a moment for the page to update
    await page.waitForTimeout(1000);
    
    // Check that the product is in the order summary
    await expect(page.locator('.product-name')).toHaveText('Teorie účetnictví - příklady, 362');
  },{ timeout: 60000 });
});

test.use({ timeout: 60000 });
test.describe('Look through PEF pictures', () => {
  test('Look through PEF pictures on PEF CZU', async ({ page }) => {
    // Visit the PEF CZU home page
     page.goto('https://www.pef.czu.cz/', {waitUntil: 'networkidle'});

    // Click on the specific navigation item
    await page.click('#nav > ul > :nth-child(6) > a');

    // Click on the first image
    await page.click(':nth-child(1) > a > .lazy');

    // Wait for the lightbox to open and navigate through images
    await page.waitForTimeout(2000); 
    await page.click('.lb-next');

    await page.waitForTimeout(2000);
    await page.click('.lb-next');

    await page.waitForTimeout(2000);
    await page.click('.lb-next');

    // Note: Playwright waits for the next button to be clickable by default, so additional waits might not be needed.
  });
});



