const { test, expect } = require('@playwright/test');

test.describe('Visit Home Prague Website', () => {
  test('Successfully loads PEF CZU home page and submits a form', async ({ page }) => {
    // Visit the website
    await page.goto('http://homeprague/');

    // Click on the 'about.php' link
    await page.click('[href="about.php"]');

    // Type into input fields
    await page.fill('#name', 'Vasily');
    await page.fill('#surname', 'Gusev');
    await page.fill('#email', 'gusevvas@mail.com');
    await page.fill('#phone', '+420666666666');
    await page.fill('#message', 'Dobrý den, \nzaujala mi Vaše nabídka bytu na Václavském náměstí' +
    '\nA proto bych chtěl se domluvit o prohlídce' +
    '\nProsím o zavolání nebo nepsání emailu.\nDěkuji.\nVasily Gusev.');

    // Click the submit button
    await page.click('#submitButton');

    // Check if the modal with the message appears
    await expect(page.locator('.modal-content > p')).toHaveText('Děkujeme Vám za odeslání nabídky, brzy Vás budeme kontaktovat.');

    // Click the close button on the modal
    await page.click('.modal-content > button');
  });
});

test.describe('Visit Home Prague Website - check search', () => {
    test('Successfully loads PEF CZU home page', async ({ page }) => {

      await page.goto('http://homeprague/');
  
      // Playwright clicks on elements directly, waiting for navigation when necessary.
      await page.click('[href="search.php"]');
  
      // For clicking on elements within containers, Playwright's selectors work similarly.
      await page.click('.dispositions > :nth-child(1) > :nth-child(3) > input');
      await page.click('.dispositions > :nth-child(2) > :nth-child(1)');
      await page.click('.dispositions > :nth-child(2) > :nth-child(3)');
      await page.click('.localities > :nth-child(1) > :nth-child(2)');
  
      // Assertions in Playwright use the expect API.
      await expect(page.locator(':nth-child(1) > .property-info > .description')).toHaveText('Pronájem bytu 1+kk');
      await expect(page.locator(':nth-child(2) > .property-info > .description')).toHaveText('Prodej bytu 3+kk');
    });
  });

  test.describe('Check the offer on Home Prague Website', () => {
    test('Successfully loads home page', async ({ page }) => {
      await page.goto('http://homeprague/');
      await page.click('[href="detail.php?property=1"] > .property-item > .property-image > img');
      //waits 2 sec
      await page.waitForTimeout(2000);
      //clicks on the next picture
      await page.click('[src="properties/1/2.png"]');
      //waits 2 sec
      await page.waitForTimeout(2000);
      //clicks on the next picture
      await page.click('[src="properties/1/3.png"]');
      
      await page.waitForTimeout(2000);
      await page.click('[src="properties/1/4.png"]');
  
      await page.waitForTimeout(2000);
      const description = await page.locator('.property-description > :nth-child(2)').textContent();
      //cheks the description
      expect(description.trim()).toBe(
        'Tento byt 1+kk na Lázeňské ulici v Praze 1, na Malé Straně, představuje skutečnou oázu klidu a luxusu. Obývací prostor je navržen s otevřeným konceptem, spojujícím spánek, odpočinek a pracovní činnosti v harmonickém celku. Vyznačuje se moderním designem, jemnými tkaninami a teplými neutrálními tóny, které vytvářejí pocit klidu a pohody. Ložnice je vybavena velkou a pohodlnou postelí, ideální pro odpočinek po dlouhém dni. Dominantní okno od podlahy až ke stropu nabízí dechberoucí výhled na noční oblohu a panorama města.'
      );
    });
  });
