import io.github.bonigarcia.wdm.WebDriverManager;
import org.junit.After;
import org.openqa.selenium.*;
import org.junit.Assert;
import org.openqa.selenium.By;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.chrome.ChromeDriver;
import org.openqa.selenium.support.ui.ExpectedConditions;
import org.openqa.selenium.support.ui.WebDriverWait;
import org.openqa.selenium.chrome.*;

import java.time.Duration;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;


public class SeleniumTest {
    public void visitPEFCZUWebsite(){
        WebDriver driver = new ChromeDriver();
        WebDriverWait wait = new WebDriverWait(driver, Duration.ofSeconds(5)); // 5 seconds wait
        try{
        // Visit the PEF CZU home page
        driver.get("https://www.pef.czu.cz/");

        // Click on the second item in the navigation menu
        WebElement secondMenuItem = wait.until(ExpectedConditions.visibilityOfElementLocated(By.cssSelector("#nav > ul > :nth-child(2) > a")));
        secondMenuItem.click();

        // Click on the fifth item under a specific role in the navigation menu
        driver.findElement(By.cssSelector("#nav > [role=\"menubar\"] > li.active > ul > :nth-child(5) > a")).click();

        // Click on an element specified by its aria-labelledby attribute
        WebElement articleElement = wait.until(ExpectedConditions.visibilityOfElementLocated(By.cssSelector("[aria-labelledby=\"widget-3913-item-8485\"] > article > .tileInner > .tile__data")));
        articleElement.click();

        // Check if an element with a specific ID has the expected text
        WebElement headingElement = driver.findElement(By.id("widget-283-heading"));
        assertEquals("Parkování v areálu ČZU", headingElement.getText());

        } finally {
            // Close the browser
            driver.quit();
        }
    }
    public void visitPEFCZUWebsiteNegative(){
        WebDriver driver = new ChromeDriver();
        WebDriverWait wait = new WebDriverWait(driver, Duration.ofSeconds(5)); // 5 seconds wait
        try{
            // Visit the PEF CZU home page
            driver.get("https://www.pef.czu.cz/");

            // Click on the second item in the navigation menu
            WebElement secondMenuItem = wait.until(ExpectedConditions.visibilityOfElementLocated(By.cssSelector("#nav > ul > :nth-child(2) > a")));
            secondMenuItem.click();

            // Click on the fifth item under a specific role in the navigation menu
            driver.findElement(By.cssSelector("#nav > [role=\"menubar\"] > li.active > ul > :nth-child(5) > a")).click();

            // Click on an element specified by its aria-labelledby attribute
            WebElement articleElement = wait.until(ExpectedConditions.visibilityOfElementLocated(By.cssSelector("[aria-labelledby=\"widget-3913-item-8485\"] > article > .tileInner > .tile__data")));
            articleElement.click();

            // Check if an element with a specific ID has the expected text
            WebElement headingElement = driver.findElement(By.id("widget-283-heading"));
            assertEquals("Prkování v areálu ČZU", headingElement.getText());

        } finally {
            // Close the browser
            driver.quit();
        }
    }

    public void findDekanNegative(){
        WebDriver driver = new ChromeDriver();
        try {
            // Přechod na úvodní stránku PEF CZU
            driver.get("https://www.pef.czu.cz/");


            WebElement menuItem = driver.findElement(By.cssSelector("[role='menubar'] > :nth-child(6) > a"));
            menuItem.click();

            WebDriverWait wait = new WebDriverWait(driver, Duration.ofSeconds(5));
            WebElement link = wait.until(ExpectedConditions.elementToBeClickable(By.cssSelector(":nth-child(15) > :nth-child(3) > a")));
            link.click();


        } finally {

            driver.quit();
        }
    }


    public void buyCZUBook() throws InterruptedException {
        WebDriver driver = new ChromeDriver();
        WebDriverWait wait = new WebDriverWait(driver, Duration.ofSeconds(5)); // 5 seconds wait
        try {
        // Visit the website
        driver.get("https://eshop.czu.cz/");

        // Click on the first product image
        driver.findElement(By.cssSelector(".codeblock > .category-products > .products-grid > .first > .product-image > img")).click();

        // Click on the add to cart button
        driver.findElement(By.cssSelector(".add-to-cart > .button > :nth-child(1) > span")).click();

        // Check for success message
        WebElement successMessage = wait.until(ExpectedConditions.visibilityOfElementLocated(By.cssSelector(".success-msg > ul > li > span")));
        assertEquals("Teorie účetnictví - příklady, 362 was added to your shopping cart.", successMessage.getText());

        // Navigate to the cart
        driver.findElement(By.cssSelector(".top-link-cart")).click();

        // Proceed to checkout
        driver.findElement(By.cssSelector(".totals > .checkout-types > li > .button > :nth-child(1) > span")).click();

        // Click to choose guest/register checkout
        driver.findElement(By.cssSelector(".col-1 > .form-list > :nth-child(1) > label")).click();
        driver.findElement(By.cssSelector("#onepage-guest-register-button > :nth-child(1) > span")).click();

        // Fill in billing information
        driver.findElement(By.id("billing:firstname")).sendKeys("Testovácí");
        driver.findElement(By.id("billing:lastname")).sendKeys("Uživatel");
        driver.findElement(By.id("billing:email")).sendKeys("someone@example.com");
        driver.findElement(By.id("billing:street1")).sendKeys("Nějaká adresa 1");
        driver.findElement(By.id("billing:city")).sendKeys("Praha");
        driver.findElement(By.id("billing:postcode")).sendKeys("12000");
        driver.findElement(By.id("billing:telephone")).sendKeys("666666666");

        // Proceed to the next step
        driver.findElement(By.cssSelector("#billing-buttons-container > .button > :nth-child(1) > span")).click();

        // Choose shipping method
        Thread.sleep(1000); // Explicit wait might be needed here for shipping options to load
        driver.findElement(By.cssSelector("#s_method_flatrate_flatrate")).click();
        driver.findElement(By.cssSelector("#shipping-method-buttons-container > .button > :nth-child(1) > span")).click();

        // Finalize the payment method selection
        driver.findElement(By.cssSelector("#payment-buttons-container > .button > :nth-child(1) > span")).click();

        // Wait a moment for the page to update
        Thread.sleep(1000);

        // Check that the product is in the order summary
        WebElement productName = driver.findElement(By.cssSelector(".product-name"));
        assertEquals("Teorie účetnictví - příklady, 362", productName.getText());

        } catch (InterruptedException e) {
            e.printStackTrace();
        } finally {
            // Close the browser
            driver.quit();
        }
    }

    public void lookThroughPEFPictures() throws InterruptedException{
        WebDriver driver = new ChromeDriver();
        WebDriverWait wait = new WebDriverWait(driver, Duration.ofSeconds(5));
        try {
            // Visit the PEF CZU home page
            driver.get("https://www.pef.czu.cz/");

            // Wait and click on the specific navigation item
            WebElement navItem = wait.until(ExpectedConditions.elementToBeClickable(By.cssSelector("#nav > ul > :nth-child(6) > a")));
            navItem.click();

            // Wait and click on the first image in the gallery
            WebElement firstImage = wait.until(ExpectedConditions.elementToBeClickable(By.cssSelector(":nth-child(1) > a > .lazy")));
            firstImage.click();

            // Simulate browsing through images by clicking the 'next' button three times
            for (int i = 0; i < 3; i++) {
                WebElement nextButton = wait.until(ExpectedConditions.elementToBeClickable(By.cssSelector(".lb-next")));
                nextButton.click();
                Thread.sleep(2000); // Waiting for the next image to be fully loaded/displayed
            }

        } catch (InterruptedException e) {
            e.printStackTrace();
        } finally {
            // Close the browser
            driver.quit();
        }
    }

    public void homePragueContactUs(){
        WebDriver driver = new ChromeDriver();
        WebDriverWait wait = new WebDriverWait(driver, Duration.ofSeconds(10));

        try {
            // Visit the website
            driver.get("http://homeprague/");

            // Click on the 'about.php' link
            driver.findElement(By.cssSelector("[href='about.php']")).click();

            // Type into input fields
            driver.findElement(By.id("name")).sendKeys("Vasily");
            driver.findElement(By.id("surname")).sendKeys("Gusev");
            driver.findElement(By.id("email")).sendKeys("gusevvas@mail.com");
            driver.findElement(By.id("phone")).sendKeys("+420666666666");
            driver.findElement(By.id("message")).sendKeys("Dobrý den, \nzaujala mi Vaše nabídka bytu na Václavském náměstí" +
                    "\nA proto bych chtěl se domluvit o prohlídce" +
                    "\nProsím o zavolání nebo nepsání emailu.\nDěkuji.\nVasily Gusev.");

            // Click the submit button
            driver.findElement(By.id("submitButton")).click();

            // Check if the modal with the message appears
            WebElement modalMessage = wait.until(ExpectedConditions.visibilityOfElementLocated(By.cssSelector(".modal-content > p")));
            if (modalMessage.getText().equals("Děkujeme Vám za odeslání nabídky, brzy Vás budeme kontaktovat.")) {
                System.out.println("Test Passed: Modal message is correct.");
            } else {
                System.out.println("Test Failed: Incorrect modal message.");
            }

            // Click the close button on the modal
            driver.findElement(By.cssSelector(".modal-content > button")).click();
        } finally {
            // Close browser
            driver.quit();
        }
    }

    public void homePragueCheckSearch(){
        WebDriver driver = new ChromeDriver();
        WebDriverWait wait = new WebDriverWait(driver, Duration.ofSeconds(10));

        driver.get("http://homeprague/");

        // Click on the search page link
        driver.findElement(By.cssSelector("[href='search.php']")).click();

        // Click on the specified elements
        driver.findElement(By.cssSelector(".dispositions > :nth-child(1) > :nth-child(3) > input")).click();
        driver.findElement(By.cssSelector(".dispositions > :nth-child(2) > :nth-child(1)")).click();
        driver.findElement(By.cssSelector(".dispositions > :nth-child(2) > :nth-child(3)")).click();
        driver.findElement(By.cssSelector(".localities > :nth-child(1) > :nth-child(2)")).click();

        // Assertions to verify the text of the descriptions
        assertEquals("Pronájem bytu 1+kk", driver.findElement(By.cssSelector(":nth-child(1) > .property-info > .description")).getText());
        assertEquals("Prodej bytu 3+kk", driver.findElement(By.cssSelector(":nth-child(2) > .property-info > .description")).getText());



        if (driver != null) {
            driver.quit();
        }
    }

    public void homePragueCheckOffer() throws InterruptedException {
        WebDriver driver = new ChromeDriver();
        WebDriverWait wait = new WebDriverWait(driver, Duration.ofSeconds(10));

        driver.get("http://homeprague/");
        // Click on the image link to navigate to the details page
        driver.findElement(By.cssSelector("[href='detail.php?property=1'] > .property-item > .property-image > img")).click();

        // Use Thread.sleep for waiting (not recommended for real tests, consider using WebDriverWait)
        Thread.sleep(2000);
        driver.findElement(By.cssSelector("[src='properties/1/2.png']")).click();

        Thread.sleep(2000);
        // Assuming the next steps are to ensure the images are present but not interact with them
        assertTrue(driver.findElement(By.cssSelector("[src='properties/1/3.png']")).isDisplayed());

        Thread.sleep(2000);
        assertTrue(driver.findElement(By.cssSelector("[src='properties/1/4.png']")).isDisplayed());

        Thread.sleep(2000);
        // Verify the property description text
        String description = driver.findElement(By.cssSelector(".property-description > :nth-child(2)")).getText().trim();
        assertEquals("Tento byt 1+kk na Lázeňské ulici v Praze 1, na Malé Straně, představuje skutečnou oázu klidu a luxusu. Obývací prostor je navržen s otevřeným konceptem, spojujícím spánek, odpočinek a pracovní činnosti v harmonickém celku. Vyznačuje se moderním designem, jemnými tkaninami a teplými neutrálními tóny, které vytvářejí pocit klidu a pohody. Ložnice je vybavena velkou a pohodlnou postelí, ideální pro odpočinek po dlouhém dni. Dominantní okno od podlahy až ke stropu nabízí dechberoucí výhled na noční oblohu a panorama města.", description);
    }




        public static void main(String[] args) throws InterruptedException {
        // Setup ChromeDriver using WebDriverManager
       System.setProperty("webdriver.chrome.driver", "driver/chrome-win64/chrome.exe");
      //  WebDriverManager.chromedriver().setup();
            assertEquals("Prkování v areálu ČZU", "Parkování v areálu ČZU");

            SeleniumTest seleniumTest = new SeleniumTest();
            seleniumTest.visitPEFCZUWebsite();
            seleniumTest.buyCZUBook();
            seleniumTest.lookThroughPEFPictures();

            seleniumTest.homePragueContactUs();
            seleniumTest.homePragueCheckSearch();
            seleniumTest.homePragueCheckOffer();

            seleniumTest.visitPEFCZUWebsiteNegative();
            seleniumTest.findDekanNegative();


    }
}